@@ -13,33 +13,40 @@
  *******************************************************************************/
 package org.eclipse.equinox.frameworkadmin.tests;
 
+import static org.junit.Assert.assertTrue;
+
 import java.io.File;
 import java.io.IOException;
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.URIUtil;
 import org.eclipse.equinox.frameworkadmin.BundleInfo;
 import org.eclipse.equinox.internal.provisional.frameworkadmin.*;
+import org.junit.Before;
+import org.junit.Test;
 import org.osgi.framework.BundleException;
 
 public class RemovingABundle extends FwkAdminAndSimpleConfiguratorTest {
 
-	public RemovingABundle(String name) {
-		super(name);
-	}
-
 	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		super.setUp();
 		Manipulator manipulator = createMinimalConfiguration(RemovingABundle.class.getName());
-		manipulator.getConfigData().addBundle(new BundleInfo("bundle_1", "1.0.0", URIUtil.toURI(FileLocator.resolve(Activator.getContext().getBundle().getEntry("dataFile/bundle_1"))), 4, false));
+		manipulator.getConfigData()
+				.addBundle(new BundleInfo("bundle_1", "1.0.0",
+						URIUtil.toURI(
+								FileLocator.resolve(Activator.getContext().getBundle().getEntry("dataFile/bundle_1"))),
+						4, false));
 		manipulator.save(false);
 
-		File fooINI = new File(getInstallFolder(), getLauncherName() +".ini");
-		assertEquals(fooINI.exists(), true);
+		File fooINI = new File(getInstallFolder(), getLauncherName() + ".ini");
+		assertTrue(fooINI.exists());
 		assertContent(getBundleTxt(), "bundle_1");
 	}
-	
-	public void testRemoveBundleWithoutURL() throws IllegalStateException, FrameworkAdminRuntimeException, IOException, BundleException {
+
+	@Test
+	public void testRemoveBundleWithoutURL()
+			throws IllegalStateException, FrameworkAdminRuntimeException, IOException, BundleException {
 		Manipulator m2 = getEquinoxFrameworkAdmin().getManipulator();
 
 		LauncherData launcherData2 = m2.getLauncherData();
@@ -49,7 +56,7 @@ public class RemovingABundle extends FwkAdminAndSimpleConfiguratorTest {
 		try {
 			m2.load();
 		} catch (IllegalStateException e) {
-			//TODO We ignore the framework JAR location not set exception
+			// TODO We ignore the framework JAR location not set exception
 		}
 		BundleInfo info = new BundleInfo("bundle_1", "1.0.0", null, 0, false);
 		m2.getConfigData().removeBundle(info);
