@@ -1,10 +1,16 @@
 /*******************************************************************************
- * Copyright (c) 2007 IBM Corporation and others. All rights reserved. This
+ * Copyright (c) 2007, 2018 IBM Corporation and others.
+ *
+ *
+ * This
  * program and the accompanying materials are made available under the terms of
- * the Eclipse Public License v1.0 which accompanies this distribution, and is
- * available at http://www.eclipse.org/legal/epl-v10.html
- * 
- * Contributors: 
+ * the Eclipse Public License 2.0 which accompanies this distribution, and is
+ * available at
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
+ *
+ * Contributors:
  * 	IBM Corporation - initial API and implementation
  ******************************************************************************/
 
@@ -21,11 +27,13 @@ public class Activator implements BundleActivator {
 		return context;
 	}
 
-	public void start(BundleContext context) throws Exception {
-		Activator.context = context;
+	@Override
+	public void start(BundleContext newcontext) throws Exception {
+		Activator.context = newcontext;
 	}
 
-	public void stop(BundleContext context) throws Exception {
+	@Override
+	public void stop(BundleContext newcontext) throws Exception {
 	}
 
 }
