@@ -26,7 +26,13 @@ import org.eclipse.internal.provisional.equinox.p2.jarprocessor.JarProcessorExec
 
 /**
  * The Pack200Packer expects an input containing normal ".jar" data.
+ * 
+ * @noextend This class is not intended to be subclassed by clients.
+ * @noinstantiate This class is not intended to be instantiated by clients.
+ * @noreference This class is not intended to be referenced by clients.
+ * @deprecated See <a href="https://bugs.eclipse.org/bugs/show_bug.cgi?id=572043">bug</a> for details.
  */
+@Deprecated(forRemoval = true, since = "1.2.0")
 public class Pack200OptimizerStep extends AbstractBufferingStep {
 	private static final String PACKED_SUFFIX = ".pack.gz"; //$NON-NLS-1$
 	private File incoming;
