@@ -29,6 +29,7 @@ import java.util.jar.JarOutputStream;
 import org.eclipse.core.runtime.*;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.equinox.internal.p2.artifact.processors.checksum.ChecksumUtilities;
+import org.eclipse.equinox.internal.p2.artifact.processors.pgp.PGPSignatureVerifier;
 import org.eclipse.equinox.internal.p2.artifact.repository.*;
 import org.eclipse.equinox.internal.p2.artifact.repository.Messages;
 import org.eclipse.equinox.internal.p2.core.helpers.FileUtils;
@@ -48,13 +49,12 @@ import org.eclipse.equinox.p2.metadata.index.IIndexProvider;
 import org.eclipse.equinox.p2.query.*;
 import org.eclipse.equinox.p2.repository.*;
 import org.eclipse.equinox.p2.repository.artifact.*;
-import org.eclipse.equinox.p2.repository.artifact.spi.AbstractArtifactRepository;
-import org.eclipse.equinox.p2.repository.artifact.spi.ArtifactDescriptor;
+import org.eclipse.equinox.p2.repository.artifact.spi.*;
 import org.eclipse.osgi.service.datalocation.Location;
 import org.eclipse.osgi.util.NLS;
 
 public class SimpleArtifactRepository extends AbstractArtifactRepository implements IFileArtifactRepository, IIndexProvider<IArtifactKey> {
-	/** 
+	/**
 	 * A boolean property controlling whether mirroring is enabled.
 	 */
 	public static final boolean MIRRORS_ENABLED = !"false".equals(Activator.getContext().getProperty("eclipse.p2.mirrors")); //$NON-NLS-1$//$NON-NLS-2$
@@ -85,7 +85,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 	public static final String CONTENT_FILENAME = "artifacts"; //$NON-NLS-1$
 
-	/** 
+	/**
 	 * The key for a integer property controls the maximum number
 	 * of threads that should be used when optimizing downloads from a remote
 	 * artifact repository.
@@ -152,7 +152,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 					delete(file);
 				if (getStatus().isOK())
 					throw e;
-				// if the stream has already been e.g. canceled, we can return - the status is already set correctly 
+				// if the stream has already been e.g. canceled, we can return - the status is already set correctly
 				return;
 			}
 			// if the steps ran ok and there was actual content, write the artifact descriptor
@@ -296,8 +296,8 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 		if (toDelete.isDirectory()) {
 			File[] children = toDelete.listFiles();
 			if (children != null) {
-				for (int i = 0; i < children.length; i++) {
-					delete(children[i]);
+				for (File element : children) {
+					delete(element);
 				}
 			}
 		}
@@ -458,10 +458,10 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 					return;
 			}
 
-			for (int i = 0; i < descriptors.length; i++) {
-				if (artifactDescriptors.contains(descriptors[i]))
+			for (IArtifactDescriptor descriptor : descriptors) {
+				if (artifactDescriptors.contains(descriptor))
 					continue;
-				SimpleArtifactDescriptor internalDescriptor = createInternalDescriptor(descriptors[i]);
+				SimpleArtifactDescriptor internalDescriptor = createInternalDescriptor(descriptor);
 				artifactDescriptors.add(internalDescriptor);
 				mapDescriptor(internalDescriptor);
 			}
@@ -478,6 +478,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 		Set<String> skipChecksums = ARTIFACT_MD5_CHECKSUM_ENABLED ? Collections.emptySet() : Collections.singleton(ChecksumHelper.MD5);
 		addChecksumVerifiers(descriptor, steps, skipChecksums, IArtifactDescriptor.ARTIFACT_CHECKSUM);
+		addPGPSignatureVerifier(descriptor, steps);
 
 		if (steps.isEmpty())
 			return destination;
@@ -486,6 +487,15 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 		return handler.link(stepArray, destination, monitor);
 	}
 
+	private void addPGPSignatureVerifier(IArtifactDescriptor descriptor, ArrayList<ProcessingStep> steps) {
+		if (descriptor.getProperties().containsKey(PGPSignatureVerifier.PGP_SIGNATURES_PROPERTY_NAME)) {
+			PGPSignatureVerifier step = new PGPSignatureVerifier();
+			ProcessingStepDescriptor stepDescriptor = new ProcessingStepDescriptor(PGPSignatureVerifier.ID, null, true);
+			step.initialize(getProvisioningAgent(), stepDescriptor, descriptor);
+			steps.add(step);
+		}
+	}
+
 	private OutputStream addPreSteps(ProcessingStepHandler handler, IArtifactDescriptor descriptor, OutputStream destination, IProgressMonitor monitor) {
 		ArrayList<ProcessingStep> steps = new ArrayList<>();
 		if (IArtifactDescriptor.TYPE_ZIP.equals(descriptor.getProperty(IArtifactDescriptor.DOWNLOAD_CONTENTTYPE)))
@@ -519,13 +529,13 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	}
 
 	private String bytesToHexString(byte[] bytes) {
-		StringBuffer buffer = new StringBuffer();
-		for (int i = 0; i < bytes.length; i++) {
+		StringBuilder buffer = new StringBuilder();
+		for (byte b : bytes) {
 			String hexString;
-			if (bytes[i] < 0)
-				hexString = Integer.toHexString(256 + bytes[i]);
+			if (b < 0)
+				hexString = Integer.toHexString(256 + b);
 			else
-				hexString = Integer.toHexString(bytes[i]);
+				hexString = Integer.toHexString(b);
 			if (hexString.length() == 1)
 				buffer.append("0"); //$NON-NLS-1$
 			buffer.append(hexString);
@@ -558,7 +568,8 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 		if (descriptor.getProcessingSteps().length == 0) {
 			descriptor.setProperty(ARTIFACT_UUID, null);
 			IArtifactKey key = descriptor.getArtifactKey();
-			URI result = mapper.map(getLocation(), key.getClassifier(), key.getId(), key.getVersion().toString(), descriptor.getProperty(IArtifactDescriptor.FORMAT));
+			URI result = mapper.map(getLocation(), key.getClassifier(), key.getId(), key.getVersion().toString(),
+					descriptor.getProperty(IArtifactDescriptor.FORMAT), descriptor.getProperties());
 			if (result != null) {
 				if (isFolderBased(descriptor) && URIUtil.lastSegment(result).endsWith(JAR_EXTENSION)) {
 					return URIUtil.removeFileExtension(result);
@@ -567,7 +578,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 			}
 		}
 
-		// Otherwise generate a location by creating a UUID, remembering it in the properties 
+		// Otherwise generate a location by creating a UUID, remembering it in the properties
 		// and computing the location
 		byte[] bytes = new UniversalUniqueIdentifier().toBytes();
 		descriptor.setProperty(ARTIFACT_UUID, bytesToHexString(bytes));
@@ -678,7 +689,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	 * Copy a file to an output stream.
 	 * Optionally close the streams when done.
 	 * Notify the monitor about progress we make
-	 * 
+	 *
 	 * @return the number of bytes written.
 	 */
 	private IStatus copyFileToStream(File in, OutputStream out, IProgressMonitor monitor) {
@@ -830,10 +841,10 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 		if (numberOfJobs <= 1 || (!isForceThreading() && isLocal())) {
 			SubMonitor subMonitor = SubMonitor.convert(monitor, requests.length);
 			try {
-				for (int i = 0; i < requests.length; i++) {
+				for (IArtifactRequest request : requests) {
 					if (monitor.isCanceled())
 						return Status.CANCEL_STATUS;
-					IStatus result = getArtifact(requests[i], subMonitor.newChild(1));
+					IStatus result = getArtifact(request, subMonitor.newChild(1));
 					if (!result.isOK())
 						overallStatus.add(result);
 				}
@@ -898,6 +909,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	 * for compatibility with the format used in optimized update sites.  We call
 	 * this arrangement "flat but packed".
 	 */
+	@SuppressWarnings("removal")
 	private boolean flatButPackedEnabled(IArtifactDescriptor descriptor) {
 		return Boolean.TRUE.toString().equals(getProperties().get(PUBLISH_PACK_FILES_AS_SIBLINGS)) && IArtifactDescriptor.FORMAT_PACKED.equals(descriptor.getProperty(IArtifactDescriptor.FORMAT));
 	}
@@ -907,7 +919,8 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	 */
 	private URI getLocationForPackedButFlatArtifacts(IArtifactDescriptor descriptor) {
 		IArtifactKey key = descriptor.getArtifactKey();
-		return mapper.map(getLocation(), key.getClassifier(), key.getId(), key.getVersion().toString(), descriptor.getProperty(IArtifactDescriptor.FORMAT));
+		return mapper.map(getLocation(), key.getClassifier(), key.getId(), key.getVersion().toString(),
+				descriptor.getProperty(IArtifactDescriptor.FORMAT), descriptor.getProperties());
 	}
 
 	public synchronized URI getLocation(IArtifactDescriptor descriptor) {
@@ -936,7 +949,8 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 			// if the descriptor is complete then use the mapping rules...
 			if (descriptor.getProcessingSteps().length == 0) {
 				IArtifactKey key = descriptor.getArtifactKey();
-				URI result = mapper.map(getLocation(), key.getClassifier(), key.getId(), key.getVersion().toString(), descriptor.getProperty(IArtifactDescriptor.FORMAT));
+				URI result = mapper.map(getLocation(), key.getClassifier(), key.getId(), key.getVersion().toString(),
+						descriptor.getProperty(IArtifactDescriptor.FORMAT), descriptor.getProperties());
 				if (result != null) {
 					if (isFolderBased(descriptor) && URIUtil.lastSegment(result).endsWith(JAR_EXTENSION))
 						return URIUtil.removeFileExtension(result);
@@ -948,31 +962,33 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 		} catch (URISyntaxException e) {
 			return null;
 		}
-		// in the end there is not enough information so return null 
+		// in the end there is not enough information so return null
 		return null;
 	}
 
 	/**
 	 * Returns the maximum number of concurrent download threads.
 	 */
+
 	private int getMaximumThreads() {
-		int repoMaxThreads = DEFAULT_MAX_THREADS;
-		int userMaxThreads = DEFAULT_MAX_THREADS;
-		try {
-			String maxThreadString = getProperties().get(PROP_MAX_THREADS);
-			if (maxThreadString != null)
-				repoMaxThreads = Math.max(1, Integer.parseInt(maxThreadString));
-		} catch (NumberFormatException nfe) {
-			// default number of threads
-		}
+		int maxThreads = DEFAULT_MAX_THREADS;
 		try {
 			String maxThreadString = Activator.getContext().getProperty(PROP_MAX_THREADS);
 			if (maxThreadString != null)
-				userMaxThreads = Math.max(1, Integer.parseInt(maxThreadString));
+				maxThreads = Math.max(1, Integer.parseInt(maxThreadString));
 		} catch (NumberFormatException nfe) {
 			// default number of threads
 		}
-		return Math.min(repoMaxThreads, userMaxThreads);
+		try {
+			String maxThreadString = getProperties().get(PROP_MAX_THREADS);
+			if (maxThreadString != null) {
+				int repoMaxThreads = Math.max(1, Integer.parseInt(maxThreadString));
+				maxThreads = Math.min(maxThreads, repoMaxThreads);
+			}
+		} catch (NumberFormatException nfe) {
+			// ignore repoMaxThreads
+		}
+		return maxThreads;
 	}
 
 	@Override
@@ -999,7 +1015,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 			throw new ProvisionException(new Status(IStatus.ERROR, Activator.ID, NLS.bind(Messages.no_location, newDescriptor)));
 		String file = URIUtil.toFile(newLocation).getAbsolutePath();
 
-		// TODO at this point we have to assume that the repository is file-based.  Eventually 
+		// TODO at this point we have to assume that the repository is file-based.  Eventually
 		// we should end up with writeable URLs...
 		// Make sure that the file does not exist and that the parents do
 		File outputFile = new File(file);
@@ -1024,7 +1040,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 				target = new FileOutputStream(file);
 			}
 
-			// finally create and return an output stream suitably wrapped so that when it is 
+			// finally create and return an output stream suitably wrapped so that when it is
 			// closed the repository is updated with the descriptor
 			return new ArtifactOutputStream(new BufferedOutputStream(target), newDescriptor, outputFile);
 		} catch (IOException e) {
@@ -1060,7 +1076,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	}
 
 	private Transport getTransport() {
-		return (Transport) getProvisioningAgent().getService(Transport.SERVICE_NAME);
+		return getProvisioningAgent().getService(Transport.class);
 	}
 
 	// use this method to setup any transient fields etc after the object has been restored from a stream
@@ -1096,7 +1112,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 	private boolean isFolderBased(IArtifactDescriptor descriptor) {
 		// This is called from createInternalDescriptor, so if we aren't a
-		// SimpleArtifactDescriptor then just check the descriptor properties instead 
+		// SimpleArtifactDescriptor then just check the descriptor properties instead
 		// of creating the internal descriptor.
 		SimpleArtifactDescriptor internalDescriptor = null;
 		if (descriptor instanceof SimpleArtifactDescriptor)
@@ -1141,8 +1157,8 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 			IArtifactDescriptor[] toRemove = artifactDescriptors.toArray(new IArtifactDescriptor[artifactDescriptors.size()]);
 			boolean changed = false;
-			for (int i = 0; i < toRemove.length; i++)
-				changed |= doRemoveArtifact(toRemove[i]);
+			for (IArtifactDescriptor element : toRemove)
+				changed |= doRemoveArtifact(element);
 			if (changed)
 				save();
 		} finally {
@@ -1226,8 +1242,8 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 			IArtifactDescriptor[] toRemove = getArtifactDescriptors(key);
 			boolean changed = false;
-			for (int i = 0; i < toRemove.length; i++)
-				changed |= doRemoveArtifact(toRemove[i]);
+			for (IArtifactDescriptor element : toRemove)
+				changed |= doRemoveArtifact(element);
 			if (changed)
 				save();
 		} finally {
@@ -1263,12 +1279,14 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 		if (!status.isOK()) {
 			// Transport pushes its status onto the output stream if the stream implements IStateful, to prevent
-			// duplication determine if the Status is present in the ProcessingStep status. 
+			// duplication determine if the Status is present in the ProcessingStep status.
 			boolean found = false;
 			IStatus[] stepStatusChildren = stepStatus.getChildren();
 			for (int i = 0; i < stepStatusChildren.length && !found; i++)
-				if (stepStatusChildren[i] == status)
+				if (stepStatusChildren[i] == status) {
 					found = true;
+					break;
+				}
 			if (!found)
 				result.merge(status);
 		}
@@ -1456,7 +1474,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 
 	/**
 	 * Locks the location and optionally loads the repository.
-	 * 
+	 *
 	 * @param ignoreLoad If ignoreLoad is set to true, then the location is locked
 	 *                   but the repository is not loaded.  It is expected
 	 *                   that the caller will load the repository manually
@@ -1542,7 +1560,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	}
 
 	/**
-	 * Returns true if this instance of SimpleArtifactRepository holds the lock or 
+	 * Returns true if this instance of SimpleArtifactRepository holds the lock or
 	 * this repository can't be locked at all due to permission, false otherwise.
 	 */
 	private boolean holdsLock() {
@@ -1568,7 +1586,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	 * Loads the repository from disk. This method will do nothing
 	 * if this instance of SimpleArtifactRepository holds the lock
 	 * because it will have loaded the repo when it acquired the lock.
-	 * 
+	 *
 	 * @param monitor
 	 */
 	private void load(IProgressMonitor monitor) {
@@ -1596,7 +1614,7 @@ public class SimpleArtifactRepository extends AbstractArtifactRepository impleme
 	 * Loads the repository from disk. If the last modified timestamp on the file <=
 	 * to our cache, then this method does nothing.  Otherwise the artifact repository
 	 * on disk is loaded, and reconciled with this instance of the artifact repository.
-	 * 
+	 *
 	 * @param monitor
 	 */
 	private void doLoad(IProgressMonitor monitor) {
