@@ -15,6 +15,9 @@
 package org.eclipse.equinox.p2.core;
 
 import java.security.cert.Certificate;
+import java.util.Collection;
+import java.util.Collections;
+import org.bouncycastle.openpgp.PGPPublicKey;
 
 /**
  * Service used for prompting for user information from within lower level code.
@@ -74,11 +77,43 @@ public abstract class UIServices {
 	 */
 	public static class TrustInfo {
 		private final Certificate[] trustedCertificates;
+		private final Collection<PGPPublicKey> trustedPGPKeys;
 		private final boolean saveTrustedCertificates;
 		private final boolean trustUnsigned;
 
+		/**
+		 *
+		 * @param trusted       Trusted certificates
+		 * @param save          Whether to store trusted certificates or not
+		 * @param trustUnsigned Whether to trust unsigned. <code>true</code> if
+		 *                      installation should continue despite unsigned content;
+		 *                      <code>false</code> otherwise.
+		 * @deprecated use other constructor
+		 */
+		@Deprecated
 		public TrustInfo(Certificate[] trusted, boolean save, boolean trustUnsigned) {
 			this.trustedCertificates = trusted;
+			this.trustedPGPKeys = Collections.emptyList();
+			this.saveTrustedCertificates = save;
+			this.trustUnsigned = trustUnsigned;
+		}
+
+		/**
+		 *
+		 * @param trustedCertificates Trusted certificates
+		 * @param trustedPGPKeys      Trusted PGP public keys
+		 * @param save                Whether to store trusted certificates and keys or
+		 *                            not.
+		 * @param trustUnsigned       Whether to trust unsigned. <code>true</code> if
+		 *                            installation should continue despite unsigned
+		 *                            content; <code>false</code> otherwise.
+		 * @since 2.8
+		 */
+		public TrustInfo(Collection<Certificate> trustedCertificates, Collection<PGPPublicKey> trustedPGPKeys,
+				boolean save,
+				boolean trustUnsigned) {
+			this.trustedCertificates = trustedCertificates.toArray(Certificate[]::new);
+			this.trustedPGPKeys = trustedPGPKeys;
 			this.saveTrustedCertificates = save;
 			this.trustUnsigned = trustUnsigned;
 		}
@@ -94,6 +129,15 @@ public abstract class UIServices {
 			return trustedCertificates;
 		}
 
+		/**
+		 *
+		 * @return the trusted PGP keys
+		 * @since 2.8
+		 */
+		public Collection<PGPPublicKey> getTrustedPGPKeys() {
+			return trustedPGPKeys;
+		}
+
 		/**
 		 * Return a boolean indicating whether the trusted certificates should
 		 * be persisted for future operations.
@@ -138,12 +182,16 @@ public abstract class UIServices {
 	/**
 	 * Opens a UI prompt to capture information about trusted content.
 	 *
-	 * @param untrustedChain - an array of certificate chains for which there is no current trust anchor.  May be
-	 * <code>null</code>, which means there are no untrusted certificate chains.
-	 * @param unsignedDetail - an array of strings, where each String describes content that is not signed.
-	 * May be <code>null</code>, which means there is no unsigned content
-	 * @return  the TrustInfo that describes the user's choices for trusting certificates and
-	 * unsigned content.
+	 * @param untrustedChain - an array of certificate chains for which there is no
+	 *                       current trust anchor. May be <code>null</code>, which
+	 *                       means there are no untrusted certificate chains.
+	 * @param unsignedDetail - an array of strings, where each String describes
+	 *                       content that is not signed. May be <code>null</code>,
+	 *                       which means there is no unsigned content
+	 * @return the TrustInfo that describes the user's choices for trusting
+	 *         certificates and unsigned content.
+	 * @implSpec Implementors should also override
+	 *           {@link #getTrustInfo(Certificate[][], Collection, String[])}.
 	 */
 	public abstract TrustInfo getTrustInfo(Certificate[][] untrustedChain, String[] unsignedDetail);
 
@@ -160,4 +208,26 @@ public abstract class UIServices {
 	public void showInformationMessage(String title, String text, String linkText) {
 		System.out.println(text);
 	}
+
+	/**
+	 * Opens a UI prompt to capture information about trusted content.
+	 *
+	 * @param unTrustedCertificateChains - an array of certificate chains for which
+	 *                                   there is no current trust anchor. May be
+	 *                                   <code>null</code>, which means there are no
+	 *                                   untrusted certificate chains.
+	 * @param untrustedPGPKeys           Collection of PGP signer keys that are not
+	 *                                   trusted
+	 * @param unsignedDetail             - an array of strings, where each String
+	 *                                   describes content that is not signed. May
+	 *                                   be <code>null</code>, which means there is
+	 *                                   no unsigned content
+	 * @return the TrustInfo that describes the user's choices for trusting
+	 *         certificates and unsigned content.
+	 * @since 2.8
+	 */
+	public TrustInfo getTrustInfo(Certificate[][] unTrustedCertificateChains, Collection<PGPPublicKey> untrustedPGPKeys,
+			String[] unsignedDetail) {
+		return getTrustInfo(unTrustedCertificateChains, unsignedDetail);
+	}
 }
