@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2009, 2018 IBM Corporation and others.
+ *  Copyright (c) 2009, 2021 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -35,7 +35,7 @@ import org.eclipse.equinox.internal.p2.director.PermissiveSlicer;
 import org.eclipse.equinox.internal.p2.metadata.ArtifactKey;
 import org.eclipse.equinox.internal.p2.metadata.InstallableUnit;
 import org.eclipse.equinox.p2.core.ProvisionException;
-import org.eclipse.equinox.p2.internal.repository.comparator.MD5ArtifactComparator;
+import org.eclipse.equinox.p2.internal.repository.comparator.ArtifactChecksumComparator;
 import org.eclipse.equinox.p2.internal.repository.tools.Messages;
 import org.eclipse.equinox.p2.metadata.IArtifactKey;
 import org.eclipse.equinox.p2.metadata.IInstallableUnit;
@@ -777,7 +777,7 @@ public class MirrorTaskTest extends AbstractAntProvisioningTest {
 
 			// Create a comparator element
 			AntTaskElement comparator = new AntTaskElement("comparator");
-			comparator.addAttribute("comparator", MD5ArtifactComparator.MD5_COMPARATOR_ID);
+			comparator.addAttribute("comparator", ArtifactChecksumComparator.COMPARATOR_ID + ".md5");
 			comparator.addElement(getRepositoryElement(baselineLocation.toURI(), null));
 			mirror.addElement(comparator);
 
