@@ -19,9 +19,10 @@ import org.junit.runners.Suite;
 /**
  * Performs all automated director tests.
  */
+@SuppressWarnings("removal")
 @RunWith(Suite.class)
 @Suite.SuiteClasses({ Pack200ProcessorTest.class, ZipVerifierProcessorTest.class, ChecksumVerifierTest.class,
-		ChecksumUtilitiesTest.class })
+		ChecksumUtilitiesTest.class, PGPSignatureVerifierTest.class })
 public class AllTests {
 // test suite
 }
