@@ -26,7 +26,7 @@ import org.junit.runners.Suite;
 		BatchExecuteArtifactRepositoryTest.class, Bug252308.class, Bug265577.class, Bug351944.class,
 		CompositeArtifactRepositoryTest.class, CorruptedJar.class, FoldersRepositoryTest.class,
 		JarURLArtifactRepositoryTest.class, LocationTest.class, MD5Tests.class, MirrorSelectorTest.class,
-		MirrorRequestTest.class, SimpleArtifactRepositoryTest.class, TransferTest.class
+		MirrorRequestTest.class, SimpleArtifactRepositoryTest.class, TransferTest.class, PGPTest.class
 })
 public class AllTests {
 // test suite
