@@ -7,31 +7,23 @@
  *  https://www.eclipse.org/legal/epl-2.0/
  *
  *  SPDX-License-Identifier: EPL-2.0
- * 
+ *
  *  Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.equinox.p2.tests.core;
 
-import junit.framework.*;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 /**
  * Performs all automated core tests.
  */
-public class AllTests extends TestCase {
-
-	public static Test suite() {
-		TestSuite suite = new TestSuite(AllTests.class.getName());
-		suite.addTestSuite(AggregateQueryTest.class);
-		suite.addTestSuite(BackupTest.class);
-		suite.addTestSuite(CollectorTest.class);
-		suite.addTestSuite(CompoundQueryableTest.class);
-		suite.addTestSuite(FileUtilsTest.class);
-		suite.addTestSuite(OrderedPropertiesTest.class);
-		suite.addTestSuite(ProvisioningAgentTest.class);
-		suite.addTestSuite(QueryTest.class);
-		suite.addTestSuite(URLUtilTest.class);
-		return suite;
-	}
-
+@RunWith(Suite.class)
+@Suite.SuiteClasses({ AggregateQueryTest.class, BackupTest.class, CollectorTest.class,
+		CompoundQueryableTest.class,
+		FileUtilsTest.class, OrderedPropertiesTest.class, ProvisioningAgentTest.class, QueryTest.class,
+		URLUtilTest.class })
+public class AllTests {
+// test suite
 }
