@@ -13,10 +13,13 @@
  *******************************************************************************/
 package org.eclipse.equinox.p2.tests.metadata;
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.util.Collection;
 import java.util.HashSet;
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
 import org.eclipse.equinox.p2.metadata.IInstallableUnit;
 import org.eclipse.equinox.p2.metadata.IProvidedCapability;
 import org.eclipse.equinox.p2.metadata.IRequirement;
@@ -26,8 +29,11 @@ import org.eclipse.equinox.p2.metadata.MetadataFactory.InstallableUnitFragmentDe
 import org.eclipse.equinox.p2.metadata.Version;
 import org.eclipse.equinox.p2.metadata.VersionRange;
 import org.eclipse.equinox.p2.tests.AbstractProvisioningTest;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
-public class FragmentMethodTest extends TestCase {
+public class FragmentMethodTest {
 	private static final String PROP_FRAG = "propFrag";
 	private static final String PROP_IU = "propIU";
 	private static final String TEST_REQUIRED = "testRequired";
@@ -36,9 +42,8 @@ public class FragmentMethodTest extends TestCase {
 	Collection<IProvidedCapability> iu1Caps;
 	Collection<IProvidedCapability> iu3Caps;
 
-	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	@Before
+	public void setUp() throws Exception {
 		iu1 = createIU("iu.test1");
 		iu3 = createIUFragment("iu.fragment");
 		iu1Caps = iu1.getProvidedCapabilities();
@@ -55,15 +60,15 @@ public class FragmentMethodTest extends TestCase {
 		}
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		iu1 = null;
 		iu3 = null;
 		iu1Caps = null;
 		iu3Caps = null;
-		super.tearDown();
 	}
 
+	@Test
 	public void testCapabilities() {
 		Collection<IProvidedCapability> mergedCapabilities = iu1.getProvidedCapabilities();
 		for (IProvidedCapability capability : mergedCapabilities) {
@@ -85,17 +90,6 @@ public class FragmentMethodTest extends TestCase {
 		assertEquals("The fragment capabilities should not change", initialFragmentCapabilities, iu3.getProvidedCapabilities());
 	}
 
-	protected void assertEquals(String message, Object[] expected, Object[] actual) {
-		if (expected == null && actual == null)
-			return;
-		if (expected == null || actual == null)
-			fail(message);
-		if (expected.length != actual.length)
-			fail(message);
-		for (int i = 0; i < expected.length; i++)
-			assertEquals(message, expected[i], actual[i]);
-	}
-
 	protected void assertEquals(String message, Collection<? extends Object> expected, Collection<? extends Object> actual) {
 		if (expected == null && actual == null)
 			return;
@@ -111,9 +105,10 @@ public class FragmentMethodTest extends TestCase {
 
 	public static void assertDoesNotContain(Collection<? extends Object> objects, Object searched) {
 		if (objects.contains(searched))
-			throw new AssertionFailedError("The array should not contain the searched element");
+			throw new AssertionError("The array should not contain the searched element");
 	}
 
+	@Test
 	public void testProperties() {
 		assertNotNull("The property is missing", iu3.getProperty(PROP_FRAG));
 		assertNotNull("The property is missing", iu1.getProperty(PROP_IU));
