@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2008, 2017 IBM Corporation and others.
+ *  Copyright (c) 2008, 2020 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -112,6 +112,8 @@ public class AbstractReconcilerTest extends AbstractProvisioningTest {
 			} catch (IOException e) {
 				fail("0.99", e);
 			}
+		} else if (file.getName().toLowerCase().endsWith(".dmg")) {
+			extractDmg("1.1", file);
 		} else {
 			untar("1.0", file);
 		}
@@ -120,6 +122,12 @@ public class AbstractReconcilerTest extends AbstractProvisioningTest {
 			exe = new File(output, getExeFolder() + "eclipse");
 			if (!exe.exists())
 				fail("Executable file: " + exe.getAbsolutePath() + "(or .exe) not found after extracting: " + file.getAbsolutePath() + " to: " + output);
+			if (!exe.canExecute()) {
+				// Try first to set --x--x--x, then --x------ if we can't do the former
+				if (!exe.setExecutable(true, false) || !exe.setExecutable(true, true)) {
+					fail("Executable file: " + exe.getAbsolutePath() + " is not executable");
+				}
+			}
 		}
 		initialized = true;
 	}
@@ -176,6 +184,17 @@ public class AbstractReconcilerTest extends AbstractProvisioningTest {
 		gzFile.delete();
 	}
 
+	/*
+	 * extract dmg given file in the output directory.
+	 */
+	private void extractDmg(String message, File file) {
+		output.mkdirs();
+		run(message, new String[] { "hdiutil", "attach", file.getAbsolutePath() });
+		run(message, new String[] { "cp", "-r", "/Volumes/Eclipse/Eclipse.app", output.getAbsolutePath() + "/" });
+		run(message, new String[] { "hdiutil", "detach", "/Volumes/Eclipse" });
+		run(message, new String[] { "xattr", "-rc", output.getAbsolutePath() + "/Eclipse.app" });
+	}
+
 	/*
 	 * Return a file object with a unique name in a temporary location.
 	 */
@@ -476,7 +495,7 @@ public class AbstractReconcilerTest extends AbstractProvisioningTest {
 
 	public Configuration loadConfiguration(File configLocation, File installLocation) {
 		try {
-			return Configuration.load(configLocation, installLocation.toURL());
+			return Configuration.load(configLocation, installLocation.toURI().toURL());
 		} catch (ProvisionException e) {
 			fail("Error while reading configuration from " + configLocation);
 		} catch (MalformedURLException e) {
@@ -494,7 +513,7 @@ public class AbstractReconcilerTest extends AbstractProvisioningTest {
 		File configLocation = new File(output, getRootFolder() + "configuration/org.eclipse.update/platform.xml");
 		File installLocation = new File(output, getRootFolder());
 		try {
-			configuration.save(configLocation, installLocation.toURL());
+			configuration.save(configLocation, installLocation.toURI().toURL());
 		} catch (ProvisionException e) {
 			fail(message, e);
 		} catch (MalformedURLException e) {
