@@ -74,10 +74,10 @@ public class ProfileSynchronizerTest extends AbstractProvisioningTest {
 
 	private void initializeReconciler() throws IllegalAccessException {
 		Field[] fields = org.eclipse.equinox.internal.p2.reconciler.dropins.Activator.class.getDeclaredFields();
-		for (int i = 0; i < fields.length; i++) {
-			if (fields[i].getName().equals("bundleContext")) {
-				fields[i].setAccessible(true);
-				fields[i].set(org.eclipse.equinox.internal.p2.reconciler.dropins.Activator.class, TestActivator.getContext());
+		for (Field field : fields) {
+			if (field.getName().equals("bundleContext")) {
+				field.setAccessible(true);
+				field.set(org.eclipse.equinox.internal.p2.reconciler.dropins.Activator.class, TestActivator.getContext());
 				break;
 			}
 		}
