@@ -18,8 +18,8 @@ package org.eclipse.equinox.internal.p2.ui;
 import org.eclipse.osgi.util.NLS;
 
 /**
- * Message class for provisioning UI messages.  
- * 
+ * Message class for provisioning UI messages.
+ *
  * @since 3.4
  */
 public class ProvUIMessages extends NLS {
@@ -271,11 +271,15 @@ public class ProvUIMessages extends NLS {
 	public static String RemedyElementNotHighestVersion;
 
 	public static String TrustCertificateDialog_Details;
+	public static String TrustCertificateDialog_Export;
 	public static String TrustCertificateDialog_Title;
 	public static String TrustCertificateDialog_Message;
 	public static String TrustCertificateDialog_AcceptSelectedButtonLabel;
 	public static String TrustCertificateDialog_SelectAll;
 	public static String TrustCertificateDialog_DeselectAll;
+	public static String TrustCertificateDialog_ObjectType;
+	public static String TrustCertificateDialog_Id;
+	public static String TrustCertificateDialog_Name;
 	// Operations
 	public static String UpdateManagerCompatibility_ExportSitesTitle;
 	public static String UpdateManagerCompatibility_ImportSitesTitle;
