@@ -35,8 +35,8 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.PlatformUI;
 
 /**
- * An install wizard that allows the users to browse all of the repositories
- * and search/select for items to install.
+ * An install wizard that allows the users to browse all of the repositories and
+ * search/select for items to install.
  *
  * @since 3.6
  */
@@ -46,7 +46,8 @@ public class InstallWizard extends WizardWithLicenses {
 	boolean ignoreSelectionChanges = false;
 	IStatus installHandlerStatus;
 
-	public InstallWizard(ProvisioningUI ui, InstallOperation operation, Collection<IInstallableUnit> initialSelections, LoadMetadataRepositoryJob preloadJob) {
+	public InstallWizard(ProvisioningUI ui, InstallOperation operation, Collection<IInstallableUnit> initialSelections,
+			LoadMetadataRepositoryJob preloadJob) {
 		super(ui, operation, initialSelections == null ? null : initialSelections.toArray(), preloadJob);
 		setWindowTitle(ProvUIMessages.InstallIUOperationLabel);
 		setDefaultPageImageDescriptor(ProvUIImages.getImageDescriptor(ProvUIImages.WIZARD_BANNER_INSTALL));
@@ -72,7 +73,8 @@ public class InstallWizard extends WizardWithLicenses {
 			return;
 		root = new IUElementListRoot(ui);
 		if (operation instanceof RemediationOperation) {
-			AvailableIUElement[] elements = ElementUtils.requestToElement(((RemediationOperation) operation).getCurrentRemedy(), true);
+			AvailableIUElement[] elements = ElementUtils
+					.requestToElement(((RemediationOperation) operation).getCurrentRemedy(), true);
 			root.setChildren(elements);
 			planSelections = elements;
 		} else {
@@ -81,7 +83,8 @@ public class InstallWizard extends WizardWithLicenses {
 			for (Object selectedElement : selectedElements) {
 				IInstallableUnit iu = ElementUtils.getIU(selectedElement);
 				if (iu != null) {
-					AvailableIUElement element = new AvailableIUElement(root, iu, getProfileId(), shouldShowProvisioningPlanChildren());
+					AvailableIUElement element = new AvailableIUElement(root, iu, getProfileId(),
+							shouldShowProvisioningPlanChildren());
 					list.add(element);
 					selections.add(element);
 				}
@@ -92,8 +95,7 @@ public class InstallWizard extends WizardWithLicenses {
 	}
 
 	/*
-	 * Overridden to dynamically determine which page to get
-	 * selections from.
+	 * Overridden to dynamically determine which page to get selections from.
 	 */
 	@Override
 	protected Object[] getOperationSelections() {
@@ -101,10 +103,9 @@ public class InstallWizard extends WizardWithLicenses {
 	}
 
 	/*
-	 * Get the page that is driving operation selections.  This is
-	 * usually the main page, but it could be error page if there
-	 * was a resolution error and the user decides to change selections
-	 * and try again without going back.
+	 * Get the page that is driving operation selections. This is usually the main
+	 * page, but it could be error page if there was a resolution error and the user
+	 * decides to change selections and try again without going back.
 	 */
 	protected ISelectableIUsPage getOperationSelectionsPage() {
 		IWizardPage page = getContainer().getCurrentPage();
@@ -141,14 +142,14 @@ public class InstallWizard extends WizardWithLicenses {
 	protected ProfileChangeOperation getProfileChangeOperation(Object[] elements) {
 		InstallOperation op = new InstallOperation(ui.getSession(), ElementUtils.elementsToIUs(elements));
 		op.setProfileId(getProfileId());
-		//		op.setRootMarkerKey(getRootMarkerKey());
+		// op.setRootMarkerKey(getRootMarkerKey());
 		return op;
 	}
 
 	@Override
 	protected boolean shouldUpdateErrorPageModelOnPlanChange() {
 		// We don't want the root of the error page to change unless we are on the
-		// main page.  For example, if we are on the error page, change checkmarks, and
+		// main page. For example, if we are on the error page, change checkmarks, and
 		// resolve again with an error, we wouldn't want the root items to change in the
 		// error page.
 		return getContainer().getCurrentPage() == mainPage && super.shouldUpdateErrorPageModelOnPlanChange();
@@ -161,8 +162,8 @@ public class InstallWizard extends WizardWithLicenses {
 	}
 
 	/*
-	 * overridden to ensure that the main page selections stay in synch
-	 * with changes to the error page.
+	 * overridden to ensure that the main page selections stay in synch with changes
+	 * to the error page.
 	 */
 	@Override
 	public void operationSelectionsChanged(ISelectableIUsPage page) {
@@ -171,9 +172,11 @@ public class InstallWizard extends WizardWithLicenses {
 		super.operationSelectionsChanged(page);
 		// If we are on the error page, resolution has failed.
 		// Our ability to move on depends on whether the selections have changed.
-		// If they are the same selections, then we are not complete until selections are changed.
+		// If they are the same selections, then we are not complete until selections
+		// are changed.
 		if (getOperationSelectionsPage() == errorPage)
-			((WizardPage) errorPage).setPageComplete(pageSelectionsHaveChanged(errorPage) && errorPage.getCheckedIUElements().length > 0);
+			((WizardPage) errorPage).setPageComplete(
+					pageSelectionsHaveChanged(errorPage) && errorPage.getCheckedIUElements().length > 0);
 		synchSelections(page);
 	}
 
@@ -192,34 +195,41 @@ public class InstallWizard extends WizardWithLicenses {
 	}
 
 	/*
-	 * Overridden to check whether there are UpdateManager install handlers in the item
-	 * to be installed.  Operations don't know about this compatibility issue.
+	 * Overridden to check whether there are UpdateManager install handlers in the
+	 * item to be installed. Operations don't know about this compatibility issue.
 	 */
 	@Override
 	public IStatus getCurrentStatus() {
 		IStatus originalStatus = super.getCurrentStatus();
 		int sev = originalStatus.getSeverity();
-		// Use the previously computed status if the user cancelled or if we were already in error.
-		// If we don't have an operation or a plan, we can't check this condition either, so just
+		// Use the previously computed status if the user cancelled or if we were
+		// already in error.
+		// If we don't have an operation or a plan, we can't check this condition
+		// either, so just
 		// use the normal status.
-		if (sev == IStatus.CANCEL || sev == IStatus.ERROR || operation == null || operation.getProvisioningPlan() == null) {
+		if (sev == IStatus.CANCEL || sev == IStatus.ERROR || operation == null
+				|| operation.getProvisioningPlan() == null) {
 			return originalStatus;
 		}
 		// Does the plan require install handler support?
 		installHandlerStatus = UpdateManagerCompatibility.getInstallHandlerStatus(operation.getProvisioningPlan());
 		if (!installHandlerStatus.isOK()) {
-			// Set the status into the wizard.  This ensures future calls to this method won't
+			// Set the status into the wizard. This ensures future calls to this method
+			// won't
 			// repeat the work (and prompting).
 			couldNotResolveStatus = installHandlerStatus;
 
-			// Is the update manager installer present?  If so, offer to open it.
+			// Is the update manager installer present? If so, offer to open it.
 			// In either case, the failure will be reported in this wizard.
 			if (ProvUI.isUpdateManagerInstallerPresent()) {
 				PlatformUI.getWorkbench().getDisplay().asyncExec(() -> {
 					Shell shell = ProvUI.getDefaultParentShell();
-					MessageDialog dialog = new MessageDialog(shell, ProvUIMessages.Policy_RequiresUpdateManagerTitle, null, ProvUIMessages.Policy_RequiresUpdateManagerMessage, MessageDialog.WARNING, new String[] {ProvUIMessages.LaunchUpdateManagerButton, IDialogConstants.CANCEL_LABEL}, 0);
+					MessageDialog dialog = new MessageDialog(shell, ProvUIMessages.Policy_RequiresUpdateManagerTitle,
+							null, ProvUIMessages.Policy_RequiresUpdateManagerMessage, MessageDialog.WARNING,
+							new String[] { ProvUIMessages.LaunchUpdateManagerButton, IDialogConstants.CANCEL_LABEL },
+							0);
 					if (dialog.open() == 0)
-						BusyIndicator.showWhile(shell.getDisplay(), () -> UpdateManagerCompatibility.openInstaller());
+						BusyIndicator.showWhile(shell.getDisplay(), UpdateManagerCompatibility::openInstaller);
 				});
 			}
 			return installHandlerStatus;
@@ -228,14 +238,16 @@ public class InstallWizard extends WizardWithLicenses {
 	}
 
 	/*
-	 * When we've found an install handler, that status trumps anything that the operation might have
-	 * determined.  We are relying here on the knowledge that the wizard's couldNotResolveStatus is
-	 * reset on every new resolution, so that status only holds the installHandler status when it is
-	 * the current status.  The installHandlerStatus must be non-OK for it to matter at all.
+	 * When we've found an install handler, that status trumps anything that the
+	 * operation might have determined. We are relying here on the knowledge that
+	 * the wizard's couldNotResolveStatus is reset on every new resolution, so that
+	 * status only holds the installHandler status when it is the current status.
+	 * The installHandlerStatus must be non-OK for it to matter at all.
 	 *
 	 */
 	@Override
 	public boolean statusOverridesOperation() {
-		return installHandlerStatus != null && !installHandlerStatus.isOK() && couldNotResolveStatus == installHandlerStatus;
+		return super.statusOverridesOperation() || (installHandlerStatus != null && !installHandlerStatus.isOK()
+				&& couldNotResolveStatus == installHandlerStatus);
 	}
 }
