@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2018 IBM Corporation and others.
+ * Copyright (c) 2007, 2020 IBM Corporation and others.
  * All rights reserved.
  * This program and the accompanying materials are made available under the
  * terms of the Eclipse Public License 2.0 which accompanies this distribution,
@@ -7,8 +7,8 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
- * Contributors: 
+ *
+ * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Red Hat, Inc (Krzysztof Daniel) - Bug 421935: Extend simpleconfigurator to
  * read .info files from many locations, Bug 460967
@@ -18,14 +18,15 @@ package org.eclipse.equinox.internal.simpleconfigurator;
 import java.io.*;
 import java.net.*;
 import java.util.*;
+import java.util.concurrent.CountDownLatch;
 import org.eclipse.equinox.internal.simpleconfigurator.utils.*;
 import org.osgi.framework.*;
 import org.osgi.framework.namespace.*;
+import org.osgi.framework.startlevel.BundleStartLevel;
 import org.osgi.framework.wiring.*;
 import org.osgi.resource.Namespace;
 import org.osgi.resource.Requirement;
 import org.osgi.service.packageadmin.PackageAdmin;
-import org.osgi.service.startlevel.StartLevel;
 
 class ConfigApplier {
 	private static final String LAST_BUNDLES_INFO = "last.bundles.info"; //$NON-NLS-1$
@@ -33,7 +34,6 @@ class ConfigApplier {
 
 	private final BundleContext manipulatingContext;
 	private final PackageAdmin packageAdminService;
-	private final StartLevel startLevelService;
 	private final FrameworkWiring frameworkWiring;
 	private final boolean runningOnEquinox;
 	private final boolean inDevMode;
@@ -53,11 +53,6 @@ class ConfigApplier {
 			throw new IllegalStateException("No PackageAdmin service is available."); //$NON-NLS-1$
 		packageAdminService = manipulatingContext.getService(packageAdminRef);
 
-		ServiceReference<StartLevel> startLevelRef = manipulatingContext.getServiceReference(StartLevel.class);
-		if (startLevelRef == null)
-			throw new IllegalStateException("No StartLevelService service is available."); //$NON-NLS-1$
-		startLevelService = manipulatingContext.getService(startLevelRef);
-
 		frameworkWiring = manipulatingContext.getBundle(Constants.SYSTEM_BUNDLE_LOCATION).adapt(FrameworkWiring.class);
 	}
 
@@ -106,12 +101,24 @@ class ConfigApplier {
 			if (toUninstall != null)
 				toRefresh.addAll(uninstallBundles(toUninstall));
 		}
-		refreshPackages(toRefresh.toArray(new Bundle[toRefresh.size()]), manipulatingContext);
-		if (toRefresh.size() > 0) {
-			Bundle[] additionalRefresh = getAdditionalRefresh(prevouslyResolved, toRefresh);
-			if (additionalRefresh.length > 0)
-				refreshPackages(additionalRefresh, manipulatingContext);
+		if (!toRefresh.isEmpty()) {
+			if (manipulatingContext.getBundle().getState() == Bundle.STARTING) {
+				// This is the startup of simple configurator.
+				// Do the full refresh of all bundles to force re-resolve
+				refreshAllBundles();
+			} else {
+				// In this case the platform is up, we should try to do an incremental resolve
+				// TODO consider removing this case because it can cause inconsistent results.
+				refreshPackages(toRefresh.toArray(new Bundle[toRefresh.size()]), manipulatingContext);
+				if (toRefresh.size() > 0) {
+					Bundle[] additionalRefresh = getAdditionalRefresh(prevouslyResolved, toRefresh);
+					if (additionalRefresh.length > 0)
+						refreshPackages(additionalRefresh, manipulatingContext);
+				}
 		}
+
+		}
+
 		startBundles(toStart.toArray(new Bundle[toStart.size()]));
 	}
 
@@ -220,6 +227,47 @@ class ConfigApplier {
 		return resolved;
 	}
 
+	private void refreshAllBundles() {
+		Set<Bundle> toRefresh = new HashSet<>(frameworkWiring.getRemovalPendingBundles());
+		Set<Bundle> doNotRefresh = getDoNotRefresh();
+		for (Bundle bundle : manipulatingContext.getBundles()) {
+			if (!doNotRefresh.contains(bundle)) {
+				toRefresh.add(bundle);
+			}
+		}
+
+		CountDownLatch latch = new CountDownLatch(1);
+		FrameworkListener listener = event -> {
+			if (event.getType() == FrameworkEvent.PACKAGES_REFRESHED) {
+				latch.countDown();
+			}
+		};
+		frameworkWiring.refreshBundles(toRefresh, listener);
+		try {
+			latch.await();
+		} catch (InterruptedException e) {
+			// ignore
+		}
+	}
+
+	private Set<Bundle> getDoNotRefresh() {
+		Set<Bundle> doNotRefresh = new HashSet<>();
+		doNotRefresh.add(manipulatingContext.getBundle());
+		Bundle systemBundle = manipulatingContext.getBundle(Constants.SYSTEM_BUNDLE_LOCATION);
+		doNotRefresh.add(systemBundle);
+		BundleWiring systemWiring = systemBundle.adapt(BundleWiring.class);
+		if (systemWiring != null) {
+			for (BundleWire hostWire : systemWiring.getProvidedWires(HostNamespace.HOST_NAMESPACE)) {
+				Bundle systemFragment = hostWire.getRequirer().getBundle();
+				if (systemFragment.getState() != Bundle.UNINSTALLED
+						&& systemFragment.adapt(BundleWiring.class) != null) {
+					doNotRefresh.add(systemFragment);
+				}
+			}
+		}
+		return doNotRefresh;
+	}
+
 	private Collection<Bundle> uninstallBundles(HashSet<BundleInfo> toUninstall) {
 		Collection<Bundle> removedBundles = new ArrayList<>(toUninstall.size());
 		for (BundleInfo current : toUninstall) {
@@ -244,8 +292,8 @@ class ConfigApplier {
 			List<InputStream> sourceStreams = new ArrayList<>(sourcesLocation.size() + 1);
 			sourceStreams.add(url.openStream());
 			if (Activator.EXTENDED) {
-				for (int i = 0; i < sourcesLocation.size(); i++) {
-					sourceStreams.add(new FileInputStream(sourcesLocation.get(i)));
+				for (File source : sourcesLocation) {
+					sourceStreams.add(new FileInputStream(source));
 				}
 			}
 			SimpleConfiguratorUtils.transferStreams(sourceStreams, destinationStream);
@@ -360,13 +408,13 @@ class ConfigApplier {
 				continue;
 			if (current.getBundleId() == 0)
 				continue;
-			if (packageAdminService.getBundleType(current) == PackageAdmin.BUNDLE_TYPE_FRAGMENT)
+			if (isFragment(current))
 				continue;
 			if (SimpleConfiguratorConstants.TARGET_CONFIGURATOR_NAME.equals(current.getSymbolicName()))
 				continue;
 
 			try {
-				startLevelService.setBundleStartLevel(current, startLevel);
+				current.adapt(BundleStartLevel.class).setStartLevel(startLevel);
 			} catch (IllegalArgumentException ex) {
 				Utils.log(4, null, null, "Failed to set start level of Bundle:" + element, ex); //$NON-NLS-1$
 			}
@@ -374,6 +422,11 @@ class ConfigApplier {
 		return toRefresh;
 	}
 
+	private boolean isFragment(Bundle current) {
+		BundleRevision revision = current.adapt(BundleRevision.class);
+		return (revision != null) && ((revision.getTypes() & BundleRevision.TYPE_FRAGMENT) != 0);
+	}
+
 	private void refreshPackages(Bundle[] bundles, BundleContext context) {
 		if (bundles.length == 0 || packageAdminService == null)
 			return;
@@ -396,26 +449,21 @@ class ConfigApplier {
 			}
 		}
 
-		final boolean[] flag = new boolean[] {false};
+		CountDownLatch latch = new CountDownLatch(1);
 		FrameworkListener listener = event -> {
 			if (event.getType() == FrameworkEvent.PACKAGES_REFRESHED) {
-				synchronized (flag) {
-					flag[0] = true;
-					flag.notifyAll();
-				}
+				latch.countDown();
 			}
 		};
 		context.addFrameworkListener(listener);
 		packageAdminService.refreshPackages(allSameBSNs.toArray(new Bundle[0]));
-		synchronized (flag) {
-			while (!flag[0]) {
-				try {
-					flag.wait();
-				} catch (InterruptedException e) {
-					//ignore
-				}
-			}
+
+		try {
+			latch.await();
+		} catch (InterruptedException e) {
+			// ignore
 		}
+
 		//		if (DEBUG) {
 		//			for (int i = 0; i < bundles.length; i++) {
 		//				System.out.println(SimpleConfiguratorUtils.getBundleStateString(bundles[i]));
@@ -432,7 +480,7 @@ class ConfigApplier {
 			}
 			if (bundle.getState() == Bundle.STARTING && (bundle == callingBundle || bundle == manipulatingContext.getBundle()))
 				continue;
-			if (packageAdminService.getBundleType(bundle) == PackageAdmin.BUNDLE_TYPE_FRAGMENT)
+			if (isFragment(bundle))
 				continue;
 			if (bundle.getBundleId() == 0)
 				continue;
@@ -450,8 +498,8 @@ class ConfigApplier {
 	}
 
 	/**
-	 * Uninstall bundles which are not listed on finalList.  
-	 * 
+	 * Uninstall bundles which are not listed on finalList.
+	 *
 	 * @param finalList bundles list not to be uninstalled.
 	 * @param packageAdmin package admin service.
 	 * @return Collection HashSet of bundles finally installed.
@@ -462,10 +510,11 @@ class ConfigApplier {
 		//Build a set with all the bundles from the system
 		Set<Bundle> removedBundles = new HashSet<>(allBundles.length);
 		//		configurator.setPrerequisiteBundles(allBundles);
-		for (int i = 0; i < allBundles.length; i++) {
-			if (allBundles[i].getBundleId() == 0)
+		for (Bundle allBundle : allBundles) {
+			if (allBundle.getBundleId() == 0) {
 				continue;
-			removedBundles.add(allBundles[i]);
+			}
+			removedBundles.add(allBundle);
 		}
 
 		//Remove all the bundles appearing in the final list from the set of installed bundles
@@ -501,6 +550,6 @@ class ConfigApplier {
 	}
 
 	private String getVersionRange(String version) {
-		return version == null ? null : new StringBuffer().append('[').append(version).append(',').append(version).append(']').toString();
+		return version == null ? null : new StringBuilder().append('[').append(version).append(',').append(version).append(']').toString();
 	}
 }
